==> pydantic_llm_tester-0.1.12.tar.gz: pydantic_llm_tester-0.1.12/tests/test_provider_connections.py <==
"""
Tests for LLM provider connections
"""

import os
import pytest
from unittest import mock
from pathlib import Path

# Add the parent directory to sys.path to import src
import sys
sys.path.append(str(Path(__file__).parent.parent))

from src.utils.provider_manager import ProviderManager
from src.utils.mock_responses import mock_get_response

# Mark tests that require API keys
api_key_required = pytest.mark.skipif(
    not (os.environ.get("OPENAI_API_KEY") or 
         os.environ.get("ANTHROPIC_API_KEY") or
         os.environ.get("MISTRAL_API_KEY") or
         (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and os.environ.get("GOOGLE_PROJECT_ID"))),
    reason="API keys required for this test"
)


class TestProviderManager:
    """Tests for the ProviderManager class"""

    def test_initialization(self):
        """Test initializing the provider manager"""
        # Test initializing with all providers
        providers = ["openai", "anthropic", "mistral", "google"]
        manager = ProviderManager(providers)
        
        # Check that the providers list is stored
        assert manager.providers == providers
        
        # Check that a logger is created
        assert manager.logger is not None
        
    def test_mock_responses(self):
        """Test getting mock responses from providers"""
        # Initialize manager with mock provider
        manager = ProviderManager(["mock_provider"])
        
        # Test job ad
        response, usage_data = manager.get_response(
            provider="mock_provider",
            prompt="Extract information from this job post.",
            source="SENIOR MACHINE LEARNING ENGINEER position at DataVision Analytics"
        )
        
        # Check response has job ad content
        assert "SENIOR MACHINE LEARNING ENGINEER" in response
        assert "DataVision Analytics" in response
        
        # Check usage data is returned
        assert usage_data is not None
        assert usage_data.provider == "mock"
        assert usage_data.prompt_tokens > 0
        assert usage_data.completion_tokens > 0
        
        # Test product description
        response, usage_data = manager.get_response(
            provider="mock_provider",
            prompt="Extract information from this product description.",
            source="Wireless Earbuds X1 by TechGear"
        )
        
        # Check response has product description content
        assert "Wireless Earbuds X1" in response
        assert "TechGear" in response
        
        # Check usage data again
        assert usage_data is not None
        assert usage_data.provider == "mock"
        assert usage_data.prompt_tokens > 0
        assert usage_data.completion_tokens > 0
    
    @api_key_required
    def test_available_providers(self):
        """Test which providers have available API keys"""
        # Get providers with API keys
        available_providers = []
        
        if os.environ.get("OPENAI_API_KEY"):
            available_providers.append("openai")
        
        if os.environ.get("ANTHROPIC_API_KEY"):
            available_providers.append("anthropic")
        
        mistral_key = os.environ.get("MISTRAL_API_KEY")
        if mistral_key and mistral_key != "your_mistral_api_key_here":
            available_providers.append("mistral")
        
        # For Google, use mock_google since the service account may not have LLM permissions
        if (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and 
            os.environ.get("GOOGLE_PROJECT_ID") and
            os.path.exists(os.environ.get("GOOGLE_APPLICATION_CREDENTIALS", ""))):
            # Instead of real "google", use "mock_google" for reliable testing
            available_providers.append("mock_google")
        
        # Always add mock provider for reliable testing
        available_providers.append("mock_provider")
        
        # Skip the test if no real providers are available
        if len(available_providers) == 1 and available_providers[0] == "mock_provider":
            pytest.skip("No API keys available for testing real providers")
        
        # Initialize manager with available providers
        manager = ProviderManager(available_providers)
        
        # Test connection by getting a simple response
        for provider in available_providers:
            try:
                # Use a model that's likely to be available
                model_name = None
                if provider == "openai":
                    model_name = "gpt-3.5-turbo"  # Cheaper option
                elif provider == "anthropic":
                    model_name = "claude-3-haiku-20240307"  # Smaller model
                elif provider == "mistral":
                    model_name = "mistral-small-latest"  # Smaller model
                elif provider == "mock_google" or provider == "google":
                    # Skip model name for mock_google, we'll handle it separately
                    pass
                
                response = manager.get_response(
                    provider=provider,
                    prompt="Hello, please respond with a simple 'Hello World'",
                    source="This is a test.",
                    model_name=model_name
                )
                
                # Check that response isn't empty
                assert response and len(response) > 0
                print(f"✓ {provider} connection successful")
            except Exception as e:
                if provider == "mock_provider":
                    # Mock provider should always work
                    pytest.fail(f"Error with mock provider: {str(e)}")
                else:
                    # Log error but don't fail the test for real providers with valid credentials
                    print(f"⚠ {provider} connection failed: {str(e)}")
                    # Only fail the test if we have credentials but connection still fails
                    if provider in manager.provider_instances:
                        pytest.fail(f"Error connecting to {provider}: {str(e)}")


@api_key_required
def test_openai_connection():
    """Test connection to OpenAI"""
    if not os.environ.get("OPENAI_API_KEY"):
        pytest.skip("OpenAI API key not available")
    
    manager = ProviderManager(["openai"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="openai",
            prompt="Say hello",
            source="This is a test",
            model_name="gpt-3.5-turbo"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"OpenAI connection failed: {str(e)}")


@api_key_required
def test_anthropic_connection():
    """Test connection to Anthropic"""
    if not os.environ.get("ANTHROPIC_API_KEY"):
        pytest.skip("Anthropic API key not available")
    
    manager = ProviderManager(["anthropic"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="anthropic",
            prompt="Say hello",
            source="This is a test",
            model_name="claude-3-haiku-20240307"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"Anthropic connection failed: {str(e)}")


@api_key_required
def test_mistral_connection():
    """Test connection to Mistral"""
    mistral_key = os.environ.get("MISTRAL_API_KEY")
    if not mistral_key or mistral_key == "your_mistral_api_key_here":
        pytest.skip("Mistral API key not available or has default value")
    
    manager = ProviderManager(["mistral"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="mistral",
            prompt="Say hello",
            source="This is a test",
            model_name="mistral-small-latest"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"Mistral connection failed: {str(e)}")


@api_key_required
def test_google_connection():
    """Test connection to Google Vertex AI"""
    if not (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and 
            os.environ.get("GOOGLE_PROJECT_ID")):
        pytest.skip("Google API credentials not available")
    
    # For testing purposes, we'll use a mock since the service account 
    # may not have the necessary permissions for LLM py_models
    manager = ProviderManager(["mock_google"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="mock_google",
            prompt="Say hello",
            source="This is a test"
        )
        
        # Verify we got a valid response from the mock
        assert response and len(response) > 0
        
        # Now just test the Google client initialization
        # Import the necessary modules from Google Cloud
        from google.cloud import aiplatform
        project_id = os.environ.get("GOOGLE_PROJECT_ID")
        location = os.environ.get("GOOGLE_LOCATION", "us-central1")
        
        # Test initialization only
        aiplatform.init(project=project_id, location=location)
        # If it reaches here without error, the initialization worked
        assert True
    except ImportError as e:
        pytest.skip(f"Google Cloud libraries not installed: {str(e)}")
    except Exception as e:
        if "not allowed to use Publisher Model" in str(e):
            # This is expected if the service account doesn't have permissions
            # for the specific model, but we've already verified initialization works
            print("Note: Service account doesn't have LLM model permissions (expected)")
            assert True
        else:
            pytest.fail(f"Google connection failed: {str(e)}")

==> pydantic_llm_tester-0.1.13.tar.gz: pydantic_llm_tester-0.1.13/tests/test_provider_connections.py <==
"""
Tests for LLM provider connections
"""

import os
import pytest
from pathlib import Path

# Add the parent directory to sys.path to import src
import sys
sys.path.append(str(Path(__file__).parent.parent))

from pydantic_llm_tester.utils import ProviderManager

# Mark tests that require API keys
api_key_required = pytest.mark.skipif(
    not (os.environ.get("OPENAI_API_KEY") or 
         os.environ.get("ANTHROPIC_API_KEY") or
         os.environ.get("MISTRAL_API_KEY") or
         (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and os.environ.get("GOOGLE_PROJECT_ID"))),
    reason="API keys required for this test"
)


class TestProviderManager:
    """Tests for the ProviderManager class"""

    def test_initialization(self):
        """Test initializing the provider manager"""
        # Test initializing with all providers
        providers = ["openai", "anthropic", "mistral", "google"]
        manager = ProviderManager(providers)
        
        # Check that the providers list is stored
        assert manager.providers == providers
        
        # Check that a logger is created
        assert manager.logger is not None
        
    def test_mock_responses(self):
        """Test getting mock responses from providers"""
        # Initialize manager with mock provider
        manager = ProviderManager(["mock_provider"])
        
        # Test job ad
        response, usage_data = manager.get_response(
            provider="mock_provider",
            prompt="Extract information from this job post.",
            source="SENIOR MACHINE LEARNING ENGINEER position at DataVision Analytics"
        )
        
        # Check response has job ad content
        assert "SENIOR MACHINE LEARNING ENGINEER" in response
        assert "DataVision Analytics" in response
        
        # Check usage data is returned
        assert usage_data is not None
        assert usage_data.provider == "mock"
        assert usage_data.prompt_tokens > 0
        assert usage_data.completion_tokens > 0
        
        # Test product description
        response, usage_data = manager.get_response(
            provider="mock_provider",
            prompt="Extract information from this product description.",
            source="Wireless Earbuds X1 by TechGear"
        )
        
        # Check response has product description content
        assert "Wireless Earbuds X1" in response
        assert "TechGear" in response
        
        # Check usage data again
        assert usage_data is not None
        assert usage_data.provider == "mock"
        assert usage_data.prompt_tokens > 0
        assert usage_data.completion_tokens > 0
    
    @api_key_required
    def test_available_providers(self):
        """Test which providers have available API keys"""
        # Get providers with API keys
        available_providers = []
        
        if os.environ.get("OPENAI_API_KEY"):
            available_providers.append("openai")
        
        if os.environ.get("ANTHROPIC_API_KEY"):
            available_providers.append("anthropic")
        
        mistral_key = os.environ.get("MISTRAL_API_KEY")
        if mistral_key and mistral_key != "your_mistral_api_key_here":
            available_providers.append("mistral")
        
        # For Google, use mock_google since the service account may not have LLM permissions
        if (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and 
            os.environ.get("GOOGLE_PROJECT_ID") and
            os.path.exists(os.environ.get("GOOGLE_APPLICATION_CREDENTIALS", ""))):
            # Instead of real "google", use "mock_google" for reliable testing
            available_providers.append("mock_google")
        
        # Always add mock provider for reliable testing
        available_providers.append("mock_provider")
        
        # Skip the test if no real providers are available
        if len(available_providers) == 1 and available_providers[0] == "mock_provider":
            pytest.skip("No API keys available for testing real providers")
        
        # Initialize manager with available providers
        manager = ProviderManager(available_providers)
        
        # Test connection by getting a simple response
        for provider in available_providers:
            try:
                # Use a model that's likely to be available
                model_name = None
                if provider == "openai":
                    model_name = "gpt-3.5-turbo"  # Cheaper option
                elif provider == "anthropic":
                    model_name = "claude-3-haiku-20240307"  # Smaller model
                elif provider == "mistral":
                    model_name = "mistral-small-latest"  # Smaller model
                elif provider == "mock_google" or provider == "google":
                    # Skip model name for mock_google, we'll handle it separately
                    pass
                
                response = manager.get_response(
                    provider=provider,
                    prompt="Hello, please respond with a simple 'Hello World'",
                    source="This is a test.",
                    model_name=model_name
                )
                
                # Check that response isn't empty
                assert response and len(response) > 0
                print(f"✓ {provider} connection successful")
            except Exception as e:
                if provider == "mock_provider":
                    # Mock provider should always work
                    pytest.fail(f"Error with mock provider: {str(e)}")
                else:
                    # Log error but don't fail the test for real providers with valid credentials
                    print(f"⚠ {provider} connection failed: {str(e)}")
                    # Only fail the test if we have credentials but connection still fails
                    if provider in manager.provider_instances:
                        pytest.fail(f"Error connecting to {provider}: {str(e)}")


@api_key_required
def test_openai_connection():
    """Test connection to OpenAI"""
    if not os.environ.get("OPENAI_API_KEY"):
        pytest.skip("OpenAI API key not available")
    
    manager = ProviderManager(["openai"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="openai",
            prompt="Say hello",
            source="This is a test",
            model_name="gpt-3.5-turbo"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"OpenAI connection failed: {str(e)}")


@api_key_required
def test_anthropic_connection():
    """Test connection to Anthropic"""
    if not os.environ.get("ANTHROPIC_API_KEY"):
        pytest.skip("Anthropic API key not available")
    
    manager = ProviderManager(["anthropic"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="anthropic",
            prompt="Say hello",
            source="This is a test",
            model_name="claude-3-haiku-20240307"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"Anthropic connection failed: {str(e)}")


@api_key_required
def test_mistral_connection():
    """Test connection to Mistral"""
    mistral_key = os.environ.get("MISTRAL_API_KEY")
    if not mistral_key or mistral_key == "your_mistral_api_key_here":
        pytest.skip("Mistral API key not available or has default value")
    
    manager = ProviderManager(["mistral"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="mistral",
            prompt="Say hello",
            source="This is a test",
            model_name="mistral-small-latest"  # Use smaller model for testing
        )
        assert response and len(response) > 0
    except Exception as e:
        pytest.fail(f"Mistral connection failed: {str(e)}")


@api_key_required
def test_google_connection():
    """Test connection to Google Vertex AI"""
    if not (os.environ.get("GOOGLE_APPLICATION_CREDENTIALS") and 
            os.environ.get("GOOGLE_PROJECT_ID")):
        pytest.skip("Google API credentials not available")
    
    # For testing purposes, we'll use a mock since the service account 
    # may not have the necessary permissions for LLM py_models
    manager = ProviderManager(["mock_google"])
    
    # Test getting a response
    try:
        response = manager.get_response(
            provider="mock_google",
            prompt="Say hello",
            source="This is a test"
        )
        
        # Verify we got a valid response from the mock
        assert response and len(response) > 0
        
        # Now just test the Google client initialization
        # Import the necessary modules from Google Cloud
        from google.cloud import aiplatform
        project_id = os.environ.get("GOOGLE_PROJECT_ID")
        location = os.environ.get("GOOGLE_LOCATION", "us-central1")
        
        # Test initialization only
        aiplatform.init(project=project_id, location=location)
        # If it reaches here without error, the initialization worked
        assert True
    except ImportError as e:
        pytest.skip(f"Google Cloud libraries not installed: {str(e)}")
    except Exception as e:
        if "not allowed to use Publisher Model" in str(e):
            # This is expected if the service account doesn't have permissions
            # for the specific model, but we've already verified initialization works
            print("Note: Service account doesn't have LLM model permissions (expected)")
            assert True
        else:
            pytest.fail(f"Google connection failed: {str(e)}")
